@@ -71,11 +71,9 @@ class Tasks(object):
         if request.ratio:
             payload["aspect_ratio"] = request.ratio
 
-        if request.input_reference:
+        if image_urls := request.input_reference:
             payload['model'] = request.model.replace("text-to-video", "image-to-video").replace("t2v", "i2v")
 
-            image_urls = await to_url_fal(request.input_reference, content_type="image/png")
-
             payload["image_url"] = image_urls[0]
 
             if len(image_urls) > 1:  # 首尾帧
@@ -83,10 +81,6 @@ class Tasks(object):
 
             # https://aimlapi.com/models/veo-3-1-reference-to-video
             # 模型区分 参考图 首尾帧
-        elif request.image:
-            payload['model'] = request.model.replace("text-to-video", "image-to-video").replace("t2v", "i2v")
-
-            payload["image_url"] = request.image[0]
 
         else:
             payload['model'] = request.model.replace("image-to-video", "text-to-video").replace("i2v", "t2v")
@@ -151,8 +145,8 @@ if __name__ == "__main__":
     request = SoraVideoRequest(**data)
 
     tasks = Tasks(api_key=api_key)
-    # arun(tasks.create(request))
+    arun(tasks.create(request))
 
-    task_id = "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview"
-
-    arun(tasks.get(task_id))
+    # task_id = "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview"
+    #
+    # arun(tasks.get(task_id))
