@@ -40,14 +40,13 @@ class OpenAIVideos(object):
             return Video(id=task_id)
 
     async def get(self, task_id):
-        task_id = task_id.replace("@", "/")
-
         video = Video(id=task_id)
         if api_key := await redis_aclient.get(task_id):
             api_key = api_key.decode()
         else:
             raise ValueError(f"task_id not found")
 
+        task_id = task_id.replace("@", "/")  # 还原
         if task_id.startswith("cgt-"):
             if response := await volc_videos.get_task(task_id, api_key):
                 # logger.debug(bjson(response))
@@ -91,7 +90,7 @@ if __name__ == '__main__':
     #       model=None, object='video', progress=0, remixed_from_video_id=None, seconds=None, size=None, status='queued',
     #       video_url=None, metadata=None)
 
-    task_id = "72f0462b-bc54-4941-bb97-918fa0e49167"
+    task_id = "7e726e6f-e9b1-40b3-b894-fec2d1274c53:alibaba@wan2.5-t2v-preview"
     arun(videos.get(task_id))
 
     # video = arun(videos.create(request))
