@@ -230,10 +230,11 @@ async def get_next_token(
             api_keys = []
             for api_key in df[0]:
                 if api_key:
-                    if isinstance(api_key, str):
-                        api_keys.append(api_key)
+                    if isinstance(api_key, (str, int)):
+                        api_keys.append(str(api_key))
                     else:
-                        api_key = "".join(map(lambda x: x.get('text', ""), api_key))
+                        logger.debug(api_key)
+                        api_key = "".join(map(lambda x: str(x.get('text', "")), api_key))
                         api_keys.append(api_key)
 
             # 初始化
@@ -273,10 +274,10 @@ async def get_next_token_for_polling(
     for api_key in df[0]:
         if api_key:
             if isinstance(api_key, str):
-                api_keys.append(api_key)
+                api_keys.append(str(api_key))
             else:
                 logger.debug("feishu表格数据: 非字符串")
-                api_key = "".join(map(lambda x: x.get('text', ""), api_key))
+                api_key = "".join(map(lambda x: str(x.get('text', "")), api_key))
                 api_keys.append(api_key)
 
     api_keys = np.random.choice(api_keys, size=min(max_size, len(api_keys)))
@@ -410,6 +411,7 @@ if __name__ == '__main__':
     FEISHU_URL = "https://xchatllm.feishu.cn/sheets/RIv6sAUtFhlZYItyYa6ctdv1nvb?sheet=0bcf4a"
     FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=Gvm9dt[:30]"
     FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=ydUVB1"
+    FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=rcoDg7"
 
     # FEISHU_URL="https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=Y7HVfo%5B%3A2%5D"
 
@@ -420,6 +422,7 @@ if __name__ == '__main__':
 
     # print(redis_client.lpop(FEISHU_URL))
 
-    arun(get_next_token(FEISHU_URL, ttl=100))
+    # arun(get_next_token(FEISHU_URL, ttl=100))
+    arun(get_next_token(FEISHU_URL))
 
     # print(redis_client.ttl("xx"))
