@@ -420,6 +420,41 @@ async def get_valid_token_for_fal(feishu_url: Optional[str] = None):
     return _
 
 
+@retrying()
+async def check_token_for_runware(api_key, threshold: float = 5):
+    base_url = "https://api.runware.ai/v1"
+    if not isinstance(api_key, str):
+        return await check_tokens(api_key, check_token_for_runware)
+
+    payload = [
+        {
+            "taskType": "accountManagement",
+            "taskUUID": str(uuid.uuid4()),
+            "operation": "getDetails"
+        }
+    ]
+    try:
+        client = AsyncOpenAI(base_url=base_url, api_key=api_key)
+        data = await client.post(
+            "/",
+            body=payload,
+            cast_to=object
+        )
+        balance = data['data'][0]['balance']
+        logger.debug(balance)
+
+        return balance > threshold
+
+    except TimeoutException as e:
+        raise
+
+    except Exception as e:
+        logger.error(f"Error: {e}\n{api_key}")
+        return False
+
+
+
+
 if __name__ == '__main__':
     from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series
 
@@ -459,7 +494,7 @@ if __name__ == '__main__':
     # r = arun(check_token_for_volc_with_cache(["1"]))
 
     # arun(check_token_for_volc("5f211bf8-3f7d-4c68-9346-ca103f9e6862"))
-    arun(check_token_for_volc_with_cache("c53afe3c-ea60-4d87-a676-ccd49d26da2c"))
+    # arun(check_token_for_volc_with_cache("c53afe3c-ea60-4d87-a676-ccd49d26da2c"))
     # arun(check_token_for_volc("76e3bf6d-ac4b-4fce-bbc3-90bef9ff0c30", purpose='seedance'))
     # arun(check_token_for_volc("16ccf1b7-b42c-4f86-81d8-48c5864eaaf0"))
 
@@ -478,3 +513,7 @@ if __name__ == '__main__':
     # api_key = "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"
     # # api_key = None
     # arun(check_token_for_openrouter(api_key=api_key or os.getenv("OPENROUTER_API_KEY")))
+
+    api_key = "P8nkXmMKfoPlSR3iR48Jbl4vs8aLP1TT"
+
+    arun(check_token_for_runware(api_key))
