@@ -486,6 +486,8 @@ MODEL_PRICE = {
     "o1-mini-all": 0.2,
     "o1-preview-all": 0.6,
 
+    "gpt-5.1-thinking": 0.03,
+
     "o3-mini": 0.05,
     "o3-mini-high": 0.1,
 
@@ -1268,13 +1270,20 @@ MODEL_RATIO = {
     "gpt-oss-120b": 0.05,
 
     "gpt-5": 0.625,
+    "gpt-5.1": 0.625,
+
     "gpt-5-2025-08-07": 0.625,
     "gpt-5-chat-latest": 0.625,
+    "gpt-5.1-chat-latest": 0.625,
+
     "gpt-5-mini": 0.125,
     "gpt-5-mini-2025-08-07": 0.125,
     "gpt-5-nano": 0.025,
     "gpt-5-nano-2025-08-07": 0.025,
 
+    "gpt-5.1-codex": 0.625,
+    "gpt-5.1-codex-mini": 0.125,
+
     "o1": 7.5,
     "o1-2024-12-17": 7.5,
 
@@ -1286,6 +1295,7 @@ MODEL_RATIO = {
     "o3-mini": 0.55,
     "o4-mini": 0.55,
     "gpt-image-1": 2.5,
+    "gpt-image-1-mini": 1,
 
     "o3": 1,
     "o3-2025-04-16": 1,
@@ -1446,6 +1456,8 @@ COMPLETION_RATIO = {
     "gpt-4.1-nano-2025-04-14": 4,
 
     "gpt-image-1": 8,
+    "gpt-image-1-mini": 4,
+
     "gpt-oss-20b": 4,
     "gpt-oss-120b": 4,
 
@@ -1456,6 +1468,10 @@ COMPLETION_RATIO = {
     "gpt-5-mini-2025-08-07": 8,
     "gpt-5-nano": 4,
     "gpt-5-nano-2025-08-07": 4,
+    "gpt-5.1": 8,
+    "gpt-5.1-chat-latest": 8,
+    "gpt-5.1-codex": 8,
+    "gpt-5.1-codex-mini": 8,
 
     # claude
     "claude-3-5-haiku-20241022": 5,
