@@ -18,6 +18,7 @@ from meutils.str_utils.json_utils import repair_json
 def get_headers(request: Request):
     dic = dict(request.headers)
     _dic = {k.replace('-', '_'): v for k, v in dic.items()}  # 增强兼容性
+    dic = {**dic, **_dic}
 
     if x_headers := dic.get('x-headers'):  # -H 'x-headers: {a: 1}' todo
         dic['x-headers'] = repair_json(x_headers, return_objects=True)
@@ -26,7 +27,10 @@ def get_headers(request: Request):
     if x_model_mapper := dic.get('x-model-mapper'):  #
         dic['x-model-mapper'] = eval(f"lambda r: {x_model_mapper}")
 
-    return {**dic, **_dic}
+    if _ := dic.get("param_override"):
+        dic["param_override"] = repair_json(_, return_objects=True)
+
+    return dic
 
 
 if __name__ == '__main__':
@@ -47,4 +51,3 @@ if __name__ == '__main__':
 
 
     print(get_headers())
-
